#!/var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_22ef9227-3527-47c4-8ca8-9108fa22ff8fsu9bb65n/croots/anaconda-navigator/anaconda-navigator_1653376617674/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/Anaconda-Navigator.app/Contents/MacOS/python
from subprocess import call

call(["/var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_22ef9227-3527-47c4-8ca8-9108fa22ff8fsu9bb65n/croots/anaconda-navigator/anaconda-navigator_1653376617674/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/bin/anaconda-navigator"])
